@@ -21,6 +21,7 @@ class NavigableDoc(object):
         self.pager = Pager()
         self.pager.update(self.links)
         self.url = self.pager.current
+        self.get = self.collectiondoc.get
 
     def __repr__(self):
         return "<Navigable Doc: {}>".format(self.url)
@@ -28,9 +29,6 @@ class NavigableDoc(object):
     def __str__(self):
         return self.collectiondoc
 
-    def get(self):
-        return self.collectiondoc.get
-
     def query(self, rel_type, params=None):
         """Returns constructed url with query parameters for urn
         type requested. To see which params are expected first
